@@ -78,7 +78,7 @@ impl RedisConnection {
 
     pub fn set_close_required_with_error(&mut self, err: &RedisError) {
         let close_required = match err.kind() {
-            ErrorKind::ResponseError => true,
+            ErrorKind::ResponseError => false,
             ErrorKind::AuthenticationFailed => true,
             ErrorKind::TypeError => false,
             ErrorKind::ExecAbortError => false,
@@ -89,11 +89,24 @@ impl RedisConnection {
             ErrorKind::Ask => false,
             ErrorKind::TryAgain => false,
             ErrorKind::ClusterDown => false,
-            ErrorKind::CrossSlot => true,
+            ErrorKind::CrossSlot => false,
             ErrorKind::MasterDown => false,
-            ErrorKind::IoError => true,
+            ErrorKind::IoError => {
+                // TODO, is_connection_dropped is_connection_refusal
+                //
+                true
+            }
             ErrorKind::ClientError => true,
-            ErrorKind::ExtensionError => false,
+            ErrorKind::ExtensionError => {
+                // https://github.com/redis-rs/redis-rs/blob/0.21.5/src/types.rs#L315-L319
+                // https://github.com/redis-rs/redis-rs/blob/0.21.5/src/types.rs#L367
+                //
+                match err.code() {
+                    Some("NOAUTH") => true,
+                    Some("WRONGPASS") => true,
+                    _ => true,
+                }
+            }
             ErrorKind::ReadOnly => false,
             _ => true,
         };
@@ -189,7 +202,10 @@ mod tests {
         where
             C: ConnectionLike + ConnectionCloseRequiredLike,
         {
-            let _ = redis::cmd("PING").query_async(conn).await?;
+            let _ = redis::cmd("PING").query_async(conn).await.map_err(|err| {
+                conn.set_close_required_with_error(&err);
+                err
+            })?;
             Ok(())
         }
 
