@@ -5,5 +5,8 @@ mod integration_tests {
     mod helpers;
 
     #[cfg(test)]
-    mod ping;
+    mod extension_error_with_noauth;
+
+    #[cfg(test)]
+    mod extension_error_with_wpassword;
 }
